@@ -24,7 +24,7 @@ if is_python3:
     import io as StringIO
 else:
     import StringIO
-import python_ui_encoder
+from . import python_ui_encoder
 
 BREAKPOINT_STR = '#break'
 PYTUTOR_HIDE_STR = '#pythontutor_hide:'
